/// <reference path='fourslash.ts' />

////var aa = 1;
////enum a { foo, /*enumValueName3*/

verify.completions({ marker: test.markers(), exact: undefined });
